@@ -641,7 +641,8 @@ WHERE
                 KEY__schema: template[KG__email_template__validation_schema],
                 KEY__application: template[KEY__application],
                 KEY_parameters: {
-                    "signed_up_at": datetime.now()
+                    "signed_up_at": datetime.now(),
+                    "dbms_user": sec_evt[KG__security_event__account]
                 },
                 KEY_query: f'UPDATE {data_relation} SET signed_up_at = :signed_up_at WHERE dbms_user = :dbms_user AND signed_up_at is null'  # Ignore pycharm PEP issue
             }
